@@ -4,9 +4,9 @@ function(model) {
 	msd <- apply(model.matrix(model), 2L, sd)
 	bx <- msd / response.sd
 
-	coefmat <- coefTable(model)
-	ret <- cbind(coefmat[, 1L:2L], coefmat[, 1L:2L] * bx)
+	coefmat <- coefTable(model)[, 1L:2L]
+	ret <- cbind(coefmat, coefmat * bx)
 	dimnames(ret) <- list(names(model$coefficients),
-		c("Estimate", "Std. Err.", "Beta", "Std. Err. Beta"))
+		c("Estimate", "Std. Error", "Beta", "Std. Err. Beta"))
 	return (ret)
 }
